==> nextcloud-13.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/eu.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Iruzkinak",
    "Edit comment" : "Iruzkina editatu",
    "Delete comment" : "Ezabatu iruzkina",
    "New comment …" : "Iruzkin berria...",
    "Post" : "Bidali",
    "Cancel" : "Utzi",
    "[Deleted user]" : "[Deleted user]",
    "No comments yet, start the conversation!" : "Oraindik ez dago iruzkinik, izan zaitez lehena zerbait esanez!",
    "More comments …" : "Iruzkin gehiago...",
    "Save" : "Gorde",
    "Allowed characters {count} of {max}" : "Onartutako karaktereak {max}-tik {count}",
    "Error occurred while updating comment with id {id}" : "Akats bat gertatu da {id} id duen iruzkina aldatzerakoan",
    "Error occurred while posting comment" : "Akats bat gertatu da iruzkina bidaltzerakoan",
    "_%n unread comment_::_%n unread comments_" : ["iruzkin %n irakurri gabe","%n iruzkin irakurri gabe"],
    "Comment" : "Iruzkina",
    "You commented" : "Iruzkindu duzu",
    "%1$s commented" : "%1$s iruzkin du",
    "{author} commented" : "{author}-(e)k iruzkin du",
    "You commented on %1$s" : "%1$s-en Iruzkin duzu",
    "You commented on {file}" : "{file}-en Iruzkin duzu",
    "%1$s commented on %2$s" : "%1$s %2$s-en iruzkin du",
    "{author} commented on {file}" : "{author}-(e)k {file}-en iruzkin du",
    "<strong>Comments</strong> for files" : "Fitxategientzako <strong>iruzkinak",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s-(e)k aipatu zaitu iruzkinean “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user}-(e)k aipatu zaitu iruzkinean “{file}”",
    "Unknown user" : "Erabiltzaile ezezaguna",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(Orain) ezabatutako erabiltzaile batek aipatu zaitu iruzkinean \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(Orain) ezabatutako erabiltzaile batek aipatu zaitu iruzkinean “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/eu.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Iruzkina editatu",
    "Delete comment" : "Ezabatu iruzkina",
    "New comment …" : "Iruzkin berria...",
    "Post" : "Bidali",
    "Cancel" : "Utzi",
    "[Deleted user]" : "[Deleted user]",
    "Comments" : "Iruzkinak",
    "No comments yet, start the conversation!" : "Oraindik ez dago iruzkinik, izan zaitez lehena zerbait esanez!",
    "More comments …" : "Iruzkin gehiago...",
    "Save" : "Gorde",
    "Allowed characters {count} of {max}" : "Onartutako karaktereak {max}-tik {count}",
    "Error occurred while updating comment with id {id}" : "Akats bat gertatu da {id} id duen iruzkina aldatzerakoan",
    "Error occurred while posting comment" : "Akats bat gertatu da iruzkina bidaltzerakoan",
    "_%n unread comment_::_%n unread comments_" : ["iruzkin %n irakurri gabe","%n iruzkin irakurri gabe"],
    "Comment" : "Iruzkina",
    "You commented" : "Iruzkindu duzu",
    "%1$s commented" : "%1$s iruzkin du",
    "{author} commented" : "{author}-(e)k iruzkin du",
    "You commented on %1$s" : "%1$s-en Iruzkin duzu",
    "You commented on {file}" : "{file}-en Iruzkin duzu",
    "%1$s commented on %2$s" : "%1$s %2$s-en iruzkin du",
    "{author} commented on {file}" : "{author}-(e)k {file}-en iruzkin du",
    "<strong>Comments</strong> for files" : "Fitxategientzako <strong>iruzkinak",
    "{user} mentioned you in a comment on “{file}”" : "{user}-(e)k aipatu zaitu iruzkinean “{file}”",
    "Unknown user" : "Erabiltzaile ezezaguna",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(Orain) ezabatutako erabiltzaile batek aipatu zaitu iruzkinean \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(Orain) ezabatutako erabiltzaile batek aipatu zaitu iruzkinean “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s-(e)k aipatu zaitu iruzkinean “%2$s”"
},
"nplurals=2; plural=(n != 1);");
